<?php

namespace App\Admin\Controllers;

use App\Models\SystemConfig;
use Dcat\Admin\Form;
use Dcat\Admin\Grid;
use Dcat\Admin\Show;
use Dcat\Admin\Http\Controllers\AdminController;

class BaseConfigController extends AdminController
{
    /**
     * Make a grid builder.
     *
     * @return Grid
     */
    protected function grid()
    {
        $grid = new Grid(new SystemConfig);

        $grid->column('id')->sortable();
        $grid->column('comment')->editable()->width(150);
        $grid->column('group')->editable();
        $grid->column('key')->editable();
        $grid->column('value')->copyable()->width(150);
        $grid->column('updated_at')->sortable();
        $grid->quickSearch(function ($model, $query) {
            $model->where('group', 'like', "%{$query}%")
                ->orWhere('key', 'like', "%{$query}%")
                ->orWhere('value', 'like', "%{$query}%");
        });
        $grid->disableActions();
        $grid->disableBatchActions();
        return $grid;
    }

    /**
     * Make a form builder.
     *
     * @return \Encore\Admin\Form
     */
    protected function form()
    {
        $form = new Form(new SystemConfig);
        $form->display('id');
        $form->text('comment');
        $form->text('group');
        $form->text('key');
        $form->textarea('value');
        $form->display('created_at');
        $form->display('updated_at');

        $form->footer(function ($footer) {
            // 去掉`查看`checkbox
            $footer->disableViewCheck();
            // 去掉`继续编辑`checkbox
            $footer->disableEditingCheck();
            // 去掉`继续创建`checkbox
            $footer->disableCreatingCheck();
        });

        return $form;
    }
}
