<?php

namespace App\Admin\Controllers;

use App\Admin\Actions\Games\GameScores;
use App\Admin\Actions\Users\FansList;
use App\Admin\Actions\Users\FollowList;
use App\Admin\Actions\Users\IntegralList;
use App\Admin\Actions\Users\SetUserInfo;
use App\Admin\Actions\Users\UserAction;
use App\Admin\Actions\Users\UserAuth;
use App\Admin\Actions\Users\UserChange;
use App\Admin\Actions\Users\UsersInfo;
use App\Admin\Actions\Users\UserVip;
use App\Models\User;
use Dcat\Admin\Form;
use Dcat\Admin\Grid;
use Dcat\Admin\Show;
use Dcat\Admin\Http\Controllers\AdminController;
use Dcat\Admin\Widgets\Modal;
use Illuminate\Database\Eloquent\Model;

class UserController extends AdminController
{
    /**
     * Make a grid builder.
     *
     * @return Grid
     */
    protected function grid()
    {
        $grid = new Grid(new User());
        $grid->model()->with('user_extra')->orderBy('id', 'desc');
        $grid->column('id')->sortable();
        $grid->column('avatar')->display(function () {
            $str = "";
            $str .= "<div style='margin-right:10px;display: flex;align-items: center'>";
            $str .= '<img data-action="preview-img" src="' . $this->avatar . '" style="height:60px;width:60px;cursor:pointer;margin-right:10px;" class="img img-thumbnail">';
            $str .= '<div>';
            $str .= '<p style="margin-bottom: 5px">姓名：' . $this->name . '</p>';
            $str .= '<p style="margin-bottom: 0px">电话：' . $this->mobile . '</p>';
            $str .= '<p style="margin-bottom: 0px">邮箱：' . $this->email . '</p>';
            $str .= "</div>";
            $str .= "</div>";
            return $str;
        });

        $grid->column('sex')->using([
            0 => trans('user.fields.unknown'),
            1 => trans('user.fields.man'),
            2 => trans('user.fields.woman')])->label(['gray', 'primary', 'danger']);

        $grid->column('user_extra.integral', trans('user.fields.integral'))->display(function ($res) {
            $form = IntegralList::make()->payload(['id' => $this->id]);
            return Modal::make()
                ->lg()
                ->title(trans('user.fields.integral'))
                ->body($form)
                ->button('<i class="feather icon-align-right"></i> ' . $res);
        });

        $grid->column('user_extra.fans_count', trans('user.fields.fansNum'))->display(function ($res) {
            $form = FansList::make()->payload(['id' => $this->id]);
            return Modal::make()
                ->lg()
                ->title(trans('user.fields.fansList'))
                ->body($form)
                ->button('<i class="feather icon-align-right"></i> ' . $res);
        });

        $grid->column('user_extra.follow_count', trans('user.fields.followNum'))->display(function ($res) {
            $form = FollowList::make()->payload(['id' => $this->id]);
            return Modal::make()
                ->lg()
                ->title(trans('user.fields.followList'))
                ->body($form)
                ->button('<i class="feather icon-align-right"></i> ' . $res);
        });

        $grid->column('is_auth')->using([
            0 => trans('user.fields.unauthorized'),
            1 => trans('user.fields.organization'),
            2 => trans('user.fields.public_figure')])->label(['gray', 'success', 'red']);

        $grid->column('online', trans('user.fields.online_status'))->using([
            0 => trans('user.fields.offline'),
            1 => trans('user.fields.online')])->label(['gray', 'success']);

        $grid->column('status')->switch('success', true);
        $grid->column('created_at');

        $grid->filter(function (Grid\Filter $filter) {
            $filter->panel();
            $filter->equal('id')->width(3);
            $filter->like('mobile')->width(3);
            $filter->like('email')->width(3);
            $filter->like('name')->width(3);
            $filter->equal('sex')->select([
                1 => trans('user.fields.man'),
                2 => trans('user.fields.woman')
            ])->width(3);
            $filter->equal('is_auth')->select([
                0 => trans('user.fields.unauthorized'),
                1 => trans('user.fields.organization'),
                2 => trans('user.fields.public_figure')
            ])->width(3);
            $filter->equal('status')->select([
                0 => trans('user.fields.frozen'),
                1 => trans('user.fields.normal'),
            ])->width(3);
        });
        //操作管理
        $grid->actions(function (Grid\Displayers\Actions $actions) {
            $actions->disableView();
            $actions->append(new UserChange(User::class));
            $actions->append(new UserAuth(User::class));
            $actions->append(new GameScores('user'));
        });
        // 禁用
        $grid->disableRowSelector();
        $grid->disableCreateButton();
        $grid->disableBatchActions();

        return $grid;
    }


    /**
     * Make a form builder.
     *
     * @return Form
     */
    protected function form()
    {
        return Form::make(new User(), function (Form $form) {
            $form->display('id')->width(6);
            $form->text('name')->width(6);
            $form->image('avatar')->width(6);
            $form->text('email')->width(6);
            $form->text('mobile')->width(6);
            $form->textarea('bio');
            $form->image('bg')->width(6);
            $form->text('tencent_im_user_id')->readOnly()->width(6);
            $form->switch('status')->default(1)->width(6);
            $form->display('created_at')->width(6);
            $form->display('updated_at')->width(6);

            $form->footer(function ($footer) {
                // 去掉`查看`checkbox
                $footer->disableViewCheck();
                // 去掉`继续编辑`checkbox
                $footer->disableEditingCheck();
                // 去掉`继续创建`checkbox
                $footer->disableCreatingCheck();
            });
        });
    }
}
